import { useFormKitSchema } from "./useFormKitSchema.mjs";
export function useFormKitRepeater() {
  const { addElement, addComponent, addElementsInOuterDiv } = useFormKitSchema();
  function addInsertButton(label = "Add", innerClass = "", outerClass = "", buttonClass = "p-button-sm", iconClass = "pi pi-plus") {
    return addElementsInOuterDiv([
      addComponent("Button", { onClick: "$addNode($node)", label, class: buttonClass, icon: iconClass }, "$node.value.length == 0")
    ], innerClass, outerClass);
  }
  function addListGroupFunctions(data, addNodeDefaultObject = {}) {
    const swapElements = (array, index1, index2) => {
      array[index1] = array.splice(index2, 1, array[index1])[0];
      return array;
    };
    data.addNode = (parentNode) => () => {
      const newArray = [...parentNode.value, addNodeDefaultObject];
      parentNode.input(newArray, false);
    };
    data.removeNode = (parentNode, index) => () => {
      parentNode.input(parentNode._value.filter((_, i) => i !== index), false);
    };
    data.moveNodeUp = (parentNode, index) => () => {
      const array = [...parentNode.value];
      if (index > 0)
        parentNode.input(swapElements(array, index - 1, index), false);
    };
    data.moveNodeDown = (parentNode, index) => () => {
      const array = [...parentNode.value];
      if (index < array.length - 1)
        parentNode.input(swapElements(array, index, index + 1), false);
    };
    data.copyNode = (parentNode, index) => () => {
      const obj = parentNode.value[index];
      const newArray = [...parentNode.value, { ...obj }];
      parentNode.input(newArray, false);
    };
  }
  function addGroupButtons(innerClass = "", outerClass = "col-4", label = "Actions", help = "", render = "true") {
    const addButtonComponent = (onClick = "", label2 = "", icon = "", severity = "", render2 = "true", styleClass = "p-button-sm") => {
      return addComponent("Button", { onClick, label: label2, icon, class: styleClass, severity }, render2);
    };
    return addElementsInOuterDiv([
      addButtonComponent("$removeNode($node, $index)", "", "pi pi-times", "danger"),
      addButtonComponent("$copyNode($node, $index)", "", "pi pi-plus"),
      addButtonComponent("$moveNodeUp($node, $index)", "", "pi pi-arrow-up", "secondary", "$index != 0"),
      addElement("span", [], { class: "p-space" }, "$index == 0"),
      addButtonComponent("$moveNodeDown($node, $index)", "", "pi pi-arrow-down", "secondary", "$index < $node.value.length -1"),
      addElement("span", [], { class: "p-space" }, "$index == $node.value.length -1")
    ], `p-action-buttons ${innerClass}`, outerClass, label, help, render);
  }
  return { addInsertButton, addGroupButtons, addListGroupFunctions };
}
